==> ejc-car-api-3.0.0-20231027.032953-43-sources.jar: com/ejianc/business/car/vo/WageEnterVO.java <==
package com.ejianc.business.car.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 人员工资
 * 
 * @author generator
 * 
 */
public class WageEnterVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private String wageOrgName; // 组织名称
    private Long wageOrgId; //组织
    private Long orgId; // 单据组织id
    private String orgName; // 单据组织名称
    private Long employeeId; // 经办人
    private String employeeName; // 经办人
    private String departmentName; // 经办部门
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM",
            timezone = "GMT+8"
    )
    private Date salaryMoth; // 月份
    private BigDecimal totalSalaryMny; // 实发工资合计
    private String memo; // 备注
    private Integer billState; // 单据状态
    private String billCode; // 单据编号
    private String billStateName;
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM-dd",
            timezone = "GMT+8"
    )
    private Date billDate; // 制单日期

    private List<WageEnterDetailVO> detailList = new ArrayList<>();

    public Date getBillDate() {
        return billDate;
    }

    public void setBillDate(Date billDate) {
        this.billDate = billDate;
    }

    public List<WageEnterDetailVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<WageEnterDetailVO> detailList) {
        this.detailList = detailList;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getWageOrgName() {
        return wageOrgName;
    }

    public void setWageOrgName(String wageOrgName) {
        this.wageOrgName = wageOrgName;
    }
    @ReferSerialTransfer(referCode = "wage-user")
    public Long getWageOrgId() {
        return wageOrgId;
    }
    @ReferDeserialTransfer
    public void setWageOrgId(Long wageOrgId) {
        this.wageOrgId = wageOrgId;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Date getSalaryMoth() {
        return salaryMoth;
    }

    public void setSalaryMoth(Date salaryMoth) {
        this.salaryMoth = salaryMoth;
    }
    public BigDecimal getTotalSalaryMny() {
        return totalSalaryMny;
    }

    public void setTotalSalaryMny(BigDecimal totalSalaryMny) {
        this.totalSalaryMny = totalSalaryMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    
}

==> ejc-car-api-3.0.0-20240229.022720-60-sources.jar: com/ejianc/business/car/vo/WageEnterVO.java <==
package com.ejianc.business.car.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 人员工资
 * 
 * @author generator
 * 
 */
public class WageEnterVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private String wageOrgName; // 组织名称
    private Long wageOrgId; //组织
    private Long orgId; // 单据组织id
    private String orgName; // 单据组织名称
    private Long employeeId; // 经办人
    private String employeeName; // 经办人
    private String departmentName; // 经办部门
    private String team; // 班组
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM",
            timezone = "GMT+8"
    )
    private Date salaryMoth; // 月份
    private BigDecimal totalSalaryMny; // 实发工资合计
    private String memo; // 备注
    private Integer billState; // 单据状态
    private String billCode; // 单据编号
    private Long payUnitId; // 付款单位
    private String payUnitName; // 付款单位名称
    private String billStateName;
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM-dd",
            timezone = "GMT+8"
    )
    private Date billDate; // 制单日期

    private List<WageEnterDetailVO> detailList = new ArrayList<>();

    public Date getBillDate() {
        return billDate;
    }

    public void setBillDate(Date billDate) {
        this.billDate = billDate;
    }

    public List<WageEnterDetailVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<WageEnterDetailVO> detailList) {
        this.detailList = detailList;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getWageOrgName() {
        return wageOrgName;
    }

    public void setWageOrgName(String wageOrgName) {
        this.wageOrgName = wageOrgName;
    }
    @ReferSerialTransfer(referCode = "wage-user")
    public Long getWageOrgId() {
        return wageOrgId;
    }
    @ReferDeserialTransfer
    public void setWageOrgId(Long wageOrgId) {
        this.wageOrgId = wageOrgId;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getDepartmentName() {
        return departmentName;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getPayUnitId() {
        return payUnitId;
    }
    @ReferDeserialTransfer
    public void setPayUnitId(Long payUnitId) {
        this.payUnitId = payUnitId;
    }

    public String getPayUnitName() {
        return payUnitName;
    }

    public void setPayUnitName(String payUnitName) {
        this.payUnitName = payUnitName;
    }

    public String getTeam() {
        return team;
    }

    public void setTeam(String team) {
        this.team = team;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Date getSalaryMoth() {
        return salaryMoth;
    }

    public void setSalaryMoth(Date salaryMoth) {
        this.salaryMoth = salaryMoth;
    }
    public BigDecimal getTotalSalaryMny() {
        return totalSalaryMny;
    }

    public void setTotalSalaryMny(BigDecimal totalSalaryMny) {
        this.totalSalaryMny = totalSalaryMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    
}
